==> analytics-2.4.1701.2-sources.jar: com/zing/zalo/devicetrackingsdk/ZingAnalyticsManager.java <==
package com.zing.zalo.devicetrackingsdk;

import android.app.Activity;
import android.app.Application;
import android.content.Context;
import android.os.Bundle;
import com.zing.zalo.devicetrackingsdk.BaseAppInfo.GetInfoListener;
import com.zing.zalo.zalosdk.analytics.internal.a;
import com.zing.zalo.zalosdk.analytics.internal.b;
import com.zing.zalo.zalosdk.analytics.internal.e;
import com.zing.zalo.zalosdk.analytics.internal.f;
import com.zing.zalo.zalosdk.analytics.internal.g;
import com.zing.zalo.zalosdk.analytics.internal.h;
import com.zing.zalo.zalosdk.core.exception.InitializedException;
import com.zing.zalo.zalosdk.core.helper.Utils;
import com.zing.zalo.zalosdk.core.log.Log;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class ZingAnalyticsManager {
    public static final int REQUEST_CODE_READ_PHONE_STATE = 101;
    public static final String UNKNOWN = "unknown";
    private static ZingAnalyticsManager e;
    String a;
    Application b;
    boolean c = false;
    boolean d = true;
    private boolean f = false;
    private boolean g = false;
    private BaseAppInfoStorage h = null;
    private e i;
    private BaseAppInfo j;
    private a k;
    private String l = UNKNOWN;
    private List<Object[]> m = new ArrayList();
    private CheckPreloadListener n;

    public interface CheckPreloadListener {
        void onResult(boolean z, String str);
    }

    private void a() {
        if (!this.c) {
            final Context applicationContext = this.b.getApplicationContext();
            this.c = true;
            this.j = new BaseAppInfo(applicationContext, this.h, this.a);
            new Thread(new Runnable(this) {
                final /* synthetic */ ZingAnalyticsManager b;

                public void run() {
                    if (!this.b.c()) {
                        this.b.k = new a(applicationContext, this.b.h, this.b.i, this.b.j, this.b.a);
                        this.b.k.a(a.a);
                        this.b.k.a(a.b);
                        this.b.k.b(a.c);
                    }
                    this.b.g = true;
                }
            }).start();
        }
    }

    private void a(Application application) {
        try {
            Bundle bundle = application.getPackageManager().getApplicationInfo(application.getPackageName(), 128).metaData;
            if (bundle.containsKey("com.zalo.sdk.preloadChannel")) {
                this.l = (String) bundle.get("com.zalo.sdk.preloadChannel");
            } else {
                this.l = UNKNOWN;
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        Log.i("debuglog", "preload preloadChannel: " + this.l);
    }

    private void b() {
        if (!this.f) {
            throw new InitializedException("Missing call ZingAnalyticsManager.getInstance().init(application, appID) in Application ");
        }
    }

    private boolean c() {
        return this.g;
    }

    public static ZingAnalyticsManager getInstance() {
        if (e == null) {
            e = new ZingAnalyticsManager();
        }
        return e;
    }

    public void addEvent(String str, String str2, String str3, long j) {
        Map hashMap = new HashMap();
        hashMap.put("category", str2);
        hashMap.put("label", str3);
        hashMap.put("value", "" + j);
        addEvent(str, hashMap);
    }

    public void addEvent(String str, Map<String, String> map) {
        b();
        if (c()) {
            Map hashMap;
            if (f.d != null) {
                if (map == null) {
                    try {
                        hashMap = new HashMap();
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
                hashMap.putAll(f.d);
            }
            try {
                if (this.m.size() > 0) {
                    for (Object[] objArr : this.m) {
                        if (objArr.length == 3) {
                            this.k.a((String) objArr[0], ((Long) objArr[1]).longValue(), (Map) objArr[2]);
                        }
                    }
                    this.m.removeAll(this.m);
                }
            } catch (Exception e2) {
            }
            this.k.a(str, System.currentTimeMillis(), hashMap);
            return;
        }
        this.m.add(new Object[]{str, Long.valueOf(System.currentTimeMillis()), map});
    }

    public void addException(String str, String str2, String str3, String str4) {
        Map hashMap = new HashMap();
        hashMap.put("name", str);
        hashMap.put("message", str2);
        hashMap.put("reason", str3);
        hashMap.put("stack_trace", str4);
        hashMap.put("app_exception", "true");
        addEvent("crash_log", hashMap);
    }

    public void dispatchEvents() {
        b();
        if (c()) {
            this.k.a();
        }
    }

    public void finalize() {
        e = null;
    }

    public void forceAddEvent(String str, Map<String, String> map) {
        b();
        if (c()) {
            ((a) this.k).a(new b(str, System.currentTimeMillis(), Utils.mapToJSONObject(map)));
        }
    }

    public boolean getAutoActivityTracking() {
        return this.d;
    }

    public String getDeviceId() {
        b();
        return this.j.getDeviceId();
    }

    public String getDeviceId(GetInfoListener getInfoListener) {
        b();
        return this.j.getDeviceId(getInfoListener);
    }

    public String getDeviceId4Ads() {
        b();
        return c() ? this.j.getDeviceId4Ads() : null;
    }

    public String getDeviceId4Ads(GetInfoListener getInfoListener) {
        b();
        return c() ? this.j.getDeviceId4Ads(getInfoListener) : null;
    }

    public BaseAppInfo getDeviceTracker() {
        return this.j;
    }

    public String getPreloadChannelFromConfig() {
        return this.l;
    }

    public String getPrivateKey() {
        b();
        return c() ? this.j.getPrivateKey() : null;
    }

    public String getSDKId() {
        b();
        return c() ? this.j.getSDKId() : null;
    }

    public BaseAppInfoStorage getStorage() {
        b();
        return this.h;
    }

    public String getVersion() {
        return this.h == null ? "2.4.1701.2" : this.h.getSDKVersion();
    }

    public ZingAnalyticsManager init(Application application) {
        if (!this.f) {
            if (application == null) {
                throw new RuntimeException("Missing Application");
            }
            Log.initLogger();
            this.a = "";
            this.b = application;
            Context applicationContext = this.b.getApplicationContext();
            this.h = new BaseAppInfoStorage(applicationContext);
            this.i = new e(applicationContext);
            this.f = true;
            a(this.b);
            boolean z = false;
            try {
                Bundle bundle = this.b.getPackageManager().getApplicationInfo(this.b.getPackageName(), 128).metaData;
                if (bundle.containsKey("configCrashTracking")) {
                    z = bundle.getBoolean("configCrashTracking");
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
            f.a.a(this.b).a();
            if (z) {
                g.a.a();
            }
            a();
        }
        return this;
    }

    public ZingAnalyticsManager init(Application application, String str) {
        if (!this.f) {
            if (application == null) {
                throw new RuntimeException("Missing Application");
            }
            Log.initLogger();
            this.a = str;
            this.b = application;
            Context applicationContext = this.b.getApplicationContext();
            this.h = new BaseAppInfoStorage(applicationContext);
            this.i = new e(applicationContext);
            this.f = true;
            a(this.b);
            boolean z = false;
            try {
                Bundle bundle = this.b.getPackageManager().getApplicationInfo(this.b.getPackageName(), 128).metaData;
                if (bundle.containsKey("configCrashTracking")) {
                    z = bundle.getBoolean("configCrashTracking");
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
            f.a.a(this.b).a();
            if (z) {
                g.a.a();
            }
            a();
        }
        return this;
    }

    public void isPreload(CheckPreloadListener checkPreloadListener) {
        b();
        this.n = checkPreloadListener;
        if (this.n == null) {
            return;
        }
        if (this.k != null) {
            try {
                a aVar = (a) this.k;
                if (aVar == null) {
                    this.n.onResult(false, UNKNOWN);
                    return;
                } else if (aVar.f) {
                    Log.i("debuglog", "isPreload: isReadFilePreload just return: " + aVar.g + " : " + aVar.h);
                    this.n.onResult(aVar.g, aVar.h);
                    return;
                } else {
                    Log.i("debuglog", "still reading preload file, wait callback when finish read file");
                    aVar.a(this.n);
                    return;
                }
            } catch (Exception e) {
                this.n.onResult(false, UNKNOWN);
                e.printStackTrace();
                return;
            }
        }
        this.n.onResult(false, UNKNOWN);
    }

    public void onPause(Activity activity) {
        if (Utils.belowSandwich()) {
            h.b(this.b).b(activity);
        }
    }

    public void onRequestPermissionsResult(int i, String[] strArr, int[] iArr) {
    }

    public void onResume(Activity activity) {
        if (Utils.belowSandwich()) {
            h.b(this.b).a(activity);
        }
    }

    public void requestNewSDKID() {
        this.j.generateSDKID();
    }

    public void requestPermission(Activity activity) {
    }

    public void sendOpenView(String str) {
        long currentTimeMillis = System.currentTimeMillis();
        Map hashMap = new HashMap();
        hashMap.put("name", str);
        hashMap.put("ts", String.valueOf(currentTimeMillis));
        addEvent("start_screen", hashMap);
    }

    public void setAutoActivityTracking(boolean z) {
        this.d = z;
    }

    public void setDispatchEventsInterval(long j) {
        b();
        if (c()) {
            this.k.a(j);
        } else {
            a.b = j;
        }
    }

    public void setMaxEventsStored(int i) {
        b();
        if (c()) {
            this.k.a(i);
        } else {
            a.a = i;
        }
    }

    public void setSdkVersion(String str) {
        b();
        this.h.setSDKVersion(str);
    }

    public void setStoreEventsInterval(long j) {
        b();
        if (c()) {
            this.k.b(j);
        } else {
            a.c = j;
        }
    }

    public void storeEvents() {
        b();
        if (c()) {
            this.k.b();
        }
    }

    public void submitAppUserData(String str, String str2, String str3, String str4, AppUserDataCallback appUserDataCallback) {
        b();
        this.j.submitAppUserData(str, str2, str3, str4, appUserDataCallback);
    }
}

==> analytics-2.4.1701.3-sources.jar: com/zing/zalo/devicetrackingsdk/ZingAnalyticsManager.java <==
package com.zing.zalo.devicetrackingsdk;

import android.app.Activity;
import android.app.Application;
import android.content.Context;
import android.os.Bundle;
import com.zing.zalo.devicetrackingsdk.BaseAppInfo.GetInfoListener;
import com.zing.zalo.zalosdk.analytics.internal.a;
import com.zing.zalo.zalosdk.analytics.internal.b;
import com.zing.zalo.zalosdk.analytics.internal.e;
import com.zing.zalo.zalosdk.analytics.internal.f;
import com.zing.zalo.zalosdk.analytics.internal.g;
import com.zing.zalo.zalosdk.analytics.internal.h;
import com.zing.zalo.zalosdk.core.exception.InitializedException;
import com.zing.zalo.zalosdk.core.helper.Utils;
import com.zing.zalo.zalosdk.core.log.Log;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class ZingAnalyticsManager {
    public static final int REQUEST_CODE_READ_PHONE_STATE = 101;
    public static final String UNKNOWN = "unknown";
    private static ZingAnalyticsManager e;
    String a;
    Application b;
    boolean c = false;
    boolean d = true;
    private boolean f = false;
    private boolean g = false;
    private BaseAppInfoStorage h = null;
    private e i;
    private BaseAppInfo j;
    private a k;
    private String l = UNKNOWN;
    private List<Object[]> m = new ArrayList();
    private CheckPreloadListener n;

    public interface CheckPreloadListener {
        void onResult(boolean z, String str);
    }

    private void a() {
        if (!this.c) {
            final Context applicationContext = this.b.getApplicationContext();
            this.c = true;
            new Thread(new Runnable(this) {
                final /* synthetic */ ZingAnalyticsManager b;

                public void run() {
                    if (!this.b.c()) {
                        this.b.k = new a(applicationContext, this.b.h, this.b.i, this.b.j, this.b.a);
                        this.b.k.a(a.a);
                        this.b.k.a(a.b);
                        this.b.k.b(a.c);
                    }
                    this.b.g = true;
                }
            }).start();
        }
    }

    private void a(Application application) {
        try {
            Bundle bundle = application.getPackageManager().getApplicationInfo(application.getPackageName(), 128).metaData;
            if (bundle.containsKey("com.zalo.sdk.preloadChannel")) {
                this.l = (String) bundle.get("com.zalo.sdk.preloadChannel");
            } else {
                this.l = UNKNOWN;
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        Log.i("debuglog", "preload preloadChannel: " + this.l);
    }

    private void b() {
        if (!this.f) {
            throw new InitializedException("Missing call ZingAnalyticsManager.getInstance().init(application, appID) in Application ");
        }
    }

    private boolean c() {
        return this.g;
    }

    public static ZingAnalyticsManager getInstance() {
        if (e == null) {
            e = new ZingAnalyticsManager();
        }
        return e;
    }

    public void addEvent(String str, String str2, String str3, long j) {
        Map hashMap = new HashMap();
        hashMap.put("category", str2);
        hashMap.put("label", str3);
        hashMap.put("value", "" + j);
        addEvent(str, hashMap);
    }

    public void addEvent(String str, Map<String, String> map) {
        b();
        if (c()) {
            Map hashMap;
            if (f.d != null) {
                if (map == null) {
                    try {
                        hashMap = new HashMap();
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
                hashMap.putAll(f.d);
            }
            try {
                if (this.m.size() > 0) {
                    for (Object[] objArr : this.m) {
                        if (objArr.length == 3) {
                            this.k.a((String) objArr[0], ((Long) objArr[1]).longValue(), (Map) objArr[2]);
                        }
                    }
                    this.m.removeAll(this.m);
                }
            } catch (Exception e2) {
            }
            this.k.a(str, System.currentTimeMillis(), hashMap);
            return;
        }
        this.m.add(new Object[]{str, Long.valueOf(System.currentTimeMillis()), map});
    }

    public void addException(String str, String str2, String str3, String str4) {
        Map hashMap = new HashMap();
        hashMap.put("name", str);
        hashMap.put("message", str2);
        hashMap.put("reason", str3);
        hashMap.put("stack_trace", str4);
        hashMap.put("app_exception", "true");
        addEvent("crash_log", hashMap);
    }

    public void dispatchEvents() {
        b();
        if (c()) {
            this.k.a();
        }
    }

    public void finalize() {
        e = null;
    }

    public void forceAddEvent(String str, Map<String, String> map) {
        b();
        if (c()) {
            ((a) this.k).a(new b(str, System.currentTimeMillis(), Utils.mapToJSONObject(map)));
        }
    }

    public boolean getAutoActivityTracking() {
        return this.d;
    }

    public String getDeviceId() {
        b();
        return this.j.getDeviceId();
    }

    public String getDeviceId(GetInfoListener getInfoListener) {
        b();
        return this.j.getDeviceId(getInfoListener);
    }

    public String getDeviceId4Ads() {
        b();
        return c() ? this.j.getDeviceId4Ads() : null;
    }

    public String getDeviceId4Ads(GetInfoListener getInfoListener) {
        b();
        return c() ? this.j.getDeviceId4Ads(getInfoListener) : null;
    }

    public BaseAppInfo getDeviceTracker() {
        return this.j;
    }

    public String getPreloadChannelFromConfig() {
        return this.l;
    }

    public String getPrivateKey() {
        b();
        return c() ? this.j.getPrivateKey() : null;
    }

    public String getSDKId() {
        b();
        return c() ? this.j.getSDKId() : null;
    }

    public BaseAppInfoStorage getStorage() {
        b();
        return this.h;
    }

    public String getVersion() {
        return this.h == null ? "2.4.1701.3" : this.h.getSDKVersion();
    }

    public ZingAnalyticsManager init(Application application) {
        if (!this.f) {
            if (application == null) {
                throw new RuntimeException("Missing Application");
            }
            Log.initLogger();
            this.a = "";
            this.b = application;
            Context applicationContext = this.b.getApplicationContext();
            this.h = new BaseAppInfoStorage(applicationContext);
            this.i = new e(applicationContext);
            this.f = true;
            this.j = new BaseAppInfo(this.b.getApplicationContext(), this.h, this.a);
            a(this.b);
            boolean z = false;
            try {
                Bundle bundle = this.b.getPackageManager().getApplicationInfo(this.b.getPackageName(), 128).metaData;
                if (bundle.containsKey("configCrashTracking")) {
                    z = bundle.getBoolean("configCrashTracking");
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
            f.a.a(this.b).a();
            if (z) {
                g.a.a();
            }
            a();
        }
        return this;
    }

    public ZingAnalyticsManager init(Application application, String str) {
        if (!this.f) {
            if (application == null) {
                throw new RuntimeException("Missing Application");
            }
            Log.initLogger();
            this.a = str;
            this.b = application;
            Context applicationContext = this.b.getApplicationContext();
            this.h = new BaseAppInfoStorage(applicationContext);
            this.i = new e(applicationContext);
            this.f = true;
            this.j = new BaseAppInfo(this.b.getApplicationContext(), this.h, this.a);
            a(this.b);
            boolean z = false;
            try {
                Bundle bundle = this.b.getPackageManager().getApplicationInfo(this.b.getPackageName(), 128).metaData;
                if (bundle.containsKey("configCrashTracking")) {
                    z = bundle.getBoolean("configCrashTracking");
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
            f.a.a(this.b).a();
            if (z) {
                g.a.a();
            }
            a();
        }
        return this;
    }

    public void isPreload(CheckPreloadListener checkPreloadListener) {
        b();
        this.n = checkPreloadListener;
        if (this.n == null) {
            return;
        }
        if (this.k != null) {
            try {
                a aVar = (a) this.k;
                if (aVar == null) {
                    this.n.onResult(false, UNKNOWN);
                    return;
                } else if (aVar.f) {
                    Log.i("debuglog", "isPreload: isReadFilePreload just return: " + aVar.g + " : " + aVar.h);
                    this.n.onResult(aVar.g, aVar.h);
                    return;
                } else {
                    Log.i("debuglog", "still reading preload file, wait callback when finish read file");
                    aVar.a(this.n);
                    return;
                }
            } catch (Exception e) {
                this.n.onResult(false, UNKNOWN);
                e.printStackTrace();
                return;
            }
        }
        this.n.onResult(false, UNKNOWN);
    }

    public void onPause(Activity activity) {
        if (Utils.belowSandwich()) {
            h.b(this.b).b(activity);
        }
    }

    public void onRequestPermissionsResult(int i, String[] strArr, int[] iArr) {
    }

    public void onResume(Activity activity) {
        if (Utils.belowSandwich()) {
            h.b(this.b).a(activity);
        }
    }

    public void requestNewSDKID() {
        this.j.generateSDKID();
    }

    public void requestPermission(Activity activity) {
    }

    public void sendOpenView(String str) {
        long currentTimeMillis = System.currentTimeMillis();
        Map hashMap = new HashMap();
        hashMap.put("name", str);
        hashMap.put("ts", String.valueOf(currentTimeMillis));
        addEvent("start_screen", hashMap);
    }

    public void setAutoActivityTracking(boolean z) {
        this.d = z;
    }

    public void setDispatchEventsInterval(long j) {
        b();
        if (c()) {
            this.k.a(j);
        } else {
            a.b = j;
        }
    }

    public void setMaxEventsStored(int i) {
        b();
        if (c()) {
            this.k.a(i);
        } else {
            a.a = i;
        }
    }

    public void setSdkVersion(String str) {
        b();
        this.h.setSDKVersion(str);
    }

    public void setStoreEventsInterval(long j) {
        b();
        if (c()) {
            this.k.b(j);
        } else {
            a.c = j;
        }
    }

    public void storeEvents() {
        b();
        if (c()) {
            this.k.b();
        }
    }

    public void submitAppUserData(String str, String str2, String str3, String str4, AppUserDataCallback appUserDataCallback) {
        b();
        this.j.submitAppUserData(str, str2, str3, str4, appUserDataCallback);
    }
}
